@@ -55,108 +55,6 @@ from vermouth.molecule import Interaction
     [(0, 1), (1, 2), (2, 3), (4, 5), (5, 6), (6, 7)],
     8,
     {}),
-    # linear multiblock last
-    ("""
-    [ moleculetype ]
-    ; name nexcl.
-    PEO         1
-    ;
-    [ atoms ]
-    1  SN1a    1   PEO   CO1  1   0.000  45
-    [ moleculetype ]
-    ; name nexcl.
-    MIX         1
-    ;
-    [ atoms ]
-    1  SN1a    1   R1   C1  1   0.000  45
-    2  SN1a    1   R1   C2  1   0.000  45
-    3  SC1     2   R2   C1  2   0.000  45
-    4  SC1     2   R2   C2  2   0.000  45
-    [ bonds ]
-    ; back bone bonds
-    1  2   1   0.37 7000
-    2  3   1   0.37 7000
-    3  4   1   0.37 7000
-    """,
-    ["PEO", "MIX"],
-    [Interaction(atoms=(1, 2), parameters=['1', '0.37', '7000'], meta={}),
-     Interaction(atoms=(2, 3), parameters=['1', '0.37', '7000'], meta={}),
-     Interaction(atoms=(3, 4), parameters=['1', '0.37', '7000'], meta={})],
-    [(1, 2), (2, 3), (3, 4)],
-    5,
-    {}),
-    # linear multi-block second
-    ("""
-    [ moleculetype ]
-    ; name nexcl.
-    PEO         1
-    ;
-    [ atoms ]
-    1  SN1a    1   PEO   CO1  1   0.000  45
-    [ moleculetype ]
-    ; name nexcl.
-    MIX         1
-    ;
-    [ atoms ]
-    1  SN1a    1   R1   C1  1   0.000  45
-    2  SN1a    1   R1   C2  1   0.000  45
-    3  SC1     2   R2   C1  2   0.000  45
-    4  SC1     2   R2   C2  2   0.000  45
-    [ bonds ]
-    ; back bone bonds
-    1  2   1   0.37 7000
-    2  3   1   0.37 7000
-    3  4   1   0.37 7000
-    """,
-    ["MIX", "PEO"],
-    [Interaction(atoms=(0, 1), parameters=['1', '0.37', '7000'], meta={}),
-     Interaction(atoms=(1, 2), parameters=['1', '0.37', '7000'], meta={}),
-     Interaction(atoms=(2, 3), parameters=['1', '0.37', '7000'], meta={})],
-    [(0, 1), (1, 2), (2, 3)],
-    5,
-    {}),
-    # linear branched
-    ("""
-    [ moleculetype ]
-    ; name nexcl.
-    PEO         1
-    ;
-    [ atoms ]
-    1  SN1a    1   PEO   CO1  1   0.000  45
-    [ moleculetype ]
-    ; name nexcl.
-    MIX         1
-    ;
-    [ atoms ]
-    1  SN1a    1   R1   C1  1   0.000  45
-    2  SC1     1   R1   C1  2   0.000  45
-    3  SN1a    2   R2   C1  1   0.000  45
-    4  SC1     2   R2   C1  2   0.000  45
-    5  SN1a    3   R3   C1  1   0.000  45
-    6  SC1     3   R3   C1  2   0.000  45
-    7  SN1a    4   R2   C1  1   0.000  45
-    8  SC1     4   R2   C1  2   0.000  45
-    [ bonds ]
-    ; back bone bonds
-    1  2   1   0.44 7000
-    1  3   1   0.37 7000
-    3  4   1   0.44 7000
-    3  5   1   0.37 7000
-    3  7   1   0.37 7000
-    5  6   1   0.44 7000
-    7  8   1   0.44 7000
-    """,
-    ["PEO", "MIX"],
-    [Interaction(atoms=(1, 2), parameters=['1', '0.44', '7000'], meta={}),
-     Interaction(atoms=(1, 3), parameters=['1', '0.37', '7000'], meta={}),
-     Interaction(atoms=(3, 4), parameters=['1', '0.44', '7000'], meta={}),
-     Interaction(atoms=(3, 5), parameters=['1', '0.37', '7000'], meta={}),
-     Interaction(atoms=(3, 7), parameters=['1', '0.37', '7000'], meta={}),
-     Interaction(atoms=(5, 6), parameters=['1', '0.44', '7000'], meta={}),
-     Interaction(atoms=(7, 8), parameters=['1', '0.44', '7000'], meta={})],
-    [(1, 2), (1, 3), (3, 4), (3, 5), (3, 7), (5, 6), (7, 8)],
-    9,
-    {}),
     # test multiblock from-itp
     ("""
     [ moleculetype ]
@@ -268,8 +166,10 @@ def test_multiresidue_block(lines, monomers, bonds, edges, nnodes, from_itp):
     # map to molecule
     new_meta_mol = polyply.src.map_to_molecule.MapToMolecule(ff).run_molecule(meta_mol)
     # check that the disconnected molecule is properly done
-    for node in new_meta_mol.nodes():
-        print(new_meta_mol.nodes[node]['graph'].nodes)
+    #print(new_meta_mol.nodes)
+    for node in new_meta_mol.nodes:
+        assert len(new_meta_mol.nodes[node]['graph'].nodes) != 0
+
     assert len(new_meta_mol.molecule.nodes) == nnodes
     assert list(new_meta_mol.molecule.edges) == edges
     assert new_meta_mol.molecule.interactions['bonds'] == bonds
@@ -306,3 +206,124 @@ def test_multi_excl_block():
 
     new_meta_mol = polyply.src.map_to_molecule.MapToMolecule(ff).run_molecule(meta_mol)
     assert nx.get_node_attributes(new_meta_mol.molecule, "exclude") == {0: 1, 1: 2, 2: 2, 3: 2, 4: 2}
+
+
+@pytest.mark.parametrize('lines, monomers, bonds, edges, nnodes, from_itp', (
+    # linear multiblock last
+    ("""
+    [ moleculetype ]
+    ; name nexcl.
+    PEO         1
+    ;
+    [ atoms ]
+    1  SN1a    1   PEO   CO1  1   0.000  45
+    [ moleculetype ]
+    ; name nexcl.
+    MIX         1
+    ;
+    [ atoms ]
+    1  SN1a    1   R1   C1  1   0.000  45
+    2  SN1a    1   R1   C2  1   0.000  45
+    3  SC1     2   R2   C1  2   0.000  45
+    4  SC1     2   R2   C2  2   0.000  45
+    [ bonds ]
+    ; back bone bonds
+    1  2   1   0.37 7000
+    2  3   1   0.37 7000
+    3  4   1   0.37 7000
+    """,
+    ["PEO", "MIX"],
+    [Interaction(atoms=(1, 2), parameters=['1', '0.37', '7000'], meta={}),
+     Interaction(atoms=(2, 3), parameters=['1', '0.37', '7000'], meta={}),
+     Interaction(atoms=(3, 4), parameters=['1', '0.37', '7000'], meta={})],
+    [(1, 2), (2, 3), (3, 4)],
+    5,
+    {}),
+   # linear multi-block second
+    ("""
+    [ moleculetype ]
+    ; name nexcl.
+    PEO         1
+    ;
+    [ atoms ]
+    1  SN1a    1   PEO   CO1  1   0.000  45
+    [ moleculetype ]
+    ; name nexcl.
+    MIX         1
+    ;
+    [ atoms ]
+    1  SN1a    1   R1   C1  1   0.000  45
+    2  SN1a    1   R1   C2  1   0.000  45
+    3  SC1     2   R2   C1  2   0.000  45
+    4  SC1     2   R2   C2  2   0.000  45
+    [ bonds ]
+    ; back bone bonds
+    1  2   1   0.37 7000
+    2  3   1   0.37 7000
+    3  4   1   0.37 7000
+    """,
+    ["MIX", "PEO"],
+    [Interaction(atoms=(0, 1), parameters=['1', '0.37', '7000'], meta={}),
+     Interaction(atoms=(1, 2), parameters=['1', '0.37', '7000'], meta={}),
+     Interaction(atoms=(2, 3), parameters=['1', '0.37', '7000'], meta={})],
+    [(0, 1), (1, 2), (2, 3)],
+    5,
+    {}),
+    # linear branched
+    ("""
+    [ moleculetype ]
+    ; name nexcl.
+    PEO         1
+    ;
+    [ atoms ]
+    1  SN1a    1   PEO   CO1  1   0.000  45
+    [ moleculetype ]
+    ; name nexcl.
+    MIX         1
+    ;
+    [ atoms ]
+    1  SN1a    1   R1   C1  1   0.000  45
+    2  SC1     1   R1   C1  2   0.000  45
+    3  SN1a    2   R2   C1  1   0.000  45
+    4  SC1     2   R2   C1  2   0.000  45
+    5  SN1a    3   R3   C1  1   0.000  45
+    6  SC1     3   R3   C1  2   0.000  45
+    7  SN1a    4   R2   C1  1   0.000  45
+    8  SC1     4   R2   C1  2   0.000  45
+    [ bonds ]
+    ; back bone bonds
+    1  2   1   0.44 7000
+    1  3   1   0.37 7000
+    3  4   1   0.44 7000
+    3  5   1   0.37 7000
+    3  7   1   0.37 7000
+    5  6   1   0.44 7000
+    7  8   1   0.44 7000
+    """,
+    ["PEO", "MIX"],
+    [Interaction(atoms=(1, 2), parameters=['1', '0.44', '7000'], meta={}),
+     Interaction(atoms=(1, 3), parameters=['1', '0.37', '7000'], meta={}),
+     Interaction(atoms=(3, 4), parameters=['1', '0.44', '7000'], meta={}),
+     Interaction(atoms=(3, 5), parameters=['1', '0.37', '7000'], meta={}),
+     Interaction(atoms=(3, 7), parameters=['1', '0.37', '7000'], meta={}),
+     Interaction(atoms=(5, 6), parameters=['1', '0.44', '7000'], meta={}),
+     Interaction(atoms=(7, 8), parameters=['1', '0.44', '7000'], meta={})],
+    [(1, 2), (1, 3), (3, 4), (3, 5), (3, 7), (5, 6), (7, 8)],
+    9,
+    {}),))
+def test_riase_multiresidue_error(lines, monomers, bonds, edges, nnodes, from_itp):
+    """
+    When a single node in the meta_molecule corresponds to a multiresidue block
+    but is not labelled with from_itp an error should be raised.
+    """
+    lines = textwrap.dedent(lines).splitlines()
+    ff = vermouth.forcefield.ForceField(name='test_ff')
+    polyply.src.polyply_parser.read_polyply(lines, ff)
+    # build the meta-molecule
+    meta_mol = MetaMolecule(name="test", force_field=ff)
+    meta_mol.add_monomer(0, monomers[0], [])
+    for node, monomer in enumerate(monomers[1:]):
+        meta_mol.add_monomer(node+1, monomer, [(node, node+1)])
+    nx.set_node_attributes(meta_mol, from_itp, "from_itp")
+    with pytest.raises(IOError):
+        new_meta_mol = polyply.src.map_to_molecule.MapToMolecule(ff).run_molecule(meta_mol)
